@@ -2,13 +2,14 @@ import json
 import socketserver
 import threading
 
-from je_web_runner import execute_action
+from je_web_runner.utils.executor.action_executor import execute_action
 
 
 class TCPServerHandler(socketserver.BaseRequestHandler):
 
     def handle(self):
         command_string = str(self.request.recv(8192).strip(), encoding="utf-8")
+        socket = self.request
         print("command is: " + command_string, flush=True)
         if command_string == "quit_server":
             self.server.shutdown()
@@ -17,7 +18,11 @@ class TCPServerHandler(socketserver.BaseRequestHandler):
         else:
             try:
                 execute_str = json.loads(command_string)
-                execute_action(execute_str)
+                for execute_function, execute_return in execute_action(execute_str).items():
+                    socket.sendto(str(execute_return).encode("utf-8"), self.client_address)
+                    socket.sendto("\n".encode("utf-8"), self.client_address)
+                socket.sendto("Return_Data_Over_JE".encode("utf-8"), self.client_address)
+                socket.sendto("\n".encode("utf-8"), self.client_address)
             except Exception as error:
                 print(repr(error))
 
@@ -29,10 +34,15 @@ class TCPServer(socketserver.ThreadingMixIn, socketserver.TCPServer):
         self.close_flag: bool = False
 
 
-def start_autocontrol_socket_server(host: str = "localhost", port: int = 9941):
+def start_autocontrol_socket_server(host: str = "localhost", port: int = 9938):
     server = TCPServer((host, port), TCPServerHandler)
     server_thread = threading.Thread(target=server.serve_forever)
     server_thread.daemon = True
     server_thread.start()
     return server
 
+
+if __name__ == "__main__":
+    start_autocontrol_socket_server()
+    while True:
+        pass
